@@ -1018,7 +1018,8 @@ public class ConvTable {
             try {
                 paraProps.setPropertyValue("ParaStyleName", styleName);
                 ConvPara.setParagraphProperties(paraProps, captionParaShape, wContext.getDocInfo().compatibleDoc, ConvPara.PARA_SPACING);
-                ConvPara.setCharacterProperties(paraProps, captionCharShape, step);
+                HwpRecord_BorderFill borderFill = wContext.getBorderFill(captionCharShape.borderFillIDRef);
+                ConvPara.setCharacterProperties(paraProps, captionCharShape, borderFill, step);
                 paraProps.setPropertyValue("ParaTopMargin", Transform.translateHwp2Office(table.captionSpacing));
                 paraProps.setPropertyValue("ParaBottomMargin", Transform.translateHwp2Office(table.captionSpacing));
                 paraProps.setPropertyValue("ParaLeftMargin", Transform.translateHwp2Office(leftSpacing));
